@@ -1018,8 +1018,8 @@ class Building(_BaseGeometry):
                         for spl in sub_polys_perim + sub_polys_core:
                             sub_face = Face3D([Point3D(pt.x, pt.y, z_val) for pt in spl])
                             new_face3d_array.append(sub_face)
-                    except RuntimeError as e:
-                        print(e)  # the generation of the polyskel failed
+                    except (RuntimeError, TypeError):
+                        # the generation of the polyskel failed
                         new_face3d_array.append(floor_face)  # just use existing floor
             face3d_array = new_face3d_array  # replace with offset core/perimeter
 
