@@ -505,6 +505,32 @@ class Model(_BaseGeometry):
                     'Building "{}" was not found in the model.'.format(identifier))
         return buildings
 
+    def stories_by_identifier(self, identifiers):
+        """Get a list of Story objects in the model given Story identifiers."""
+        stories, model_stories = [], self.stories
+        for identifier in identifiers:
+            for story in model_stories:
+                if story.identifier == identifier:
+                    stories.append(story)
+                    break
+            else:
+                raise ValueError(
+                    'Story "{}" was not found in the model.'.format(identifier))
+        return stories
+
+    def room_2ds_by_identifier(self, identifiers):
+        """Get a list of Room2D objects in the model given Room2D identifiers."""
+        room_2ds, model_room_2ds = [], self.room_2ds
+        for identifier in identifiers:
+            for room in model_room_2ds:
+                if room.identifier == identifier:
+                    room_2ds.append(room)
+                    break
+            else:
+                raise ValueError(
+                    'Room2D "{}" was not found in the model.'.format(identifier))
+        return room_2ds
+
     def context_shade_by_identifier(self, identifiers):
         """Get a list of ContextShade objects in the model given ContextShade identifiers.
         """
@@ -897,7 +923,7 @@ class Model(_BaseGeometry):
 
         return models
 
-    def to_geojson_dict(self, location, point=Point2D(0, 0), tolerance=0.01):
+    def to_geojson_dict(self, location, point=Point2D(0, 0), tolerance=None):
         """Convert Dragonfly Model to a geoJSON-style Python dictionary.
 
         This dictionary can be written into a JSON, which is then a valid geoJSON
@@ -911,8 +937,8 @@ class Model(_BaseGeometry):
                 within the space of a scene. The coordinates of this point are
                 expected to be in the units of this Model. (Default: (0, 0)).
             tolerance: The minimum distance between points at which they are
-                not considered touching. Default: 0.01, suitable for objects
-                in meters.
+                not considered touching. If None, the Model's own tolerance
+                will be used. (Default: None).
 
         Returns:
             A Python dictionary in a geoJSON style with each Building in the Model
@@ -921,6 +947,13 @@ class Model(_BaseGeometry):
         # set up the base dictionary for the geoJSON
         geojson_dict = {'type': 'FeatureCollection', 'features': [], 'mappers': []}
 
+        # ensure that the Model we are working with is in meters
+        model = self
+        if self.units != 'Meters':
+            model = self.duplicate()  # duplicate to avoid editing this object
+            model.convert_to_units('Meters')
+            point = point.scale(conversion_factor_to_meters(self.units))
+
         # assign the site information in the project key
         project_dict = {
             'id': self.identifier,
@@ -930,20 +963,15 @@ class Model(_BaseGeometry):
             'elevation': location.elevation,
             'latitude': location.latitude,
             'longitude': location.longitude,
-            'time_zone': location.time_zone
+            'time_zone': location.time_zone,
+            'cad_coordinates': [point.x, point.y]
         }
         geojson_dict['project'] = project_dict
 
-        # ensure that the Model we are working with is in meters
-        model = self
-        if self.units != 'Meters':
-            model = self.duplicate()  # duplicate to avoid editing this object
-            model.convert_to_units('Meters')
-            point = point.scale(conversion_factor_to_meters(self.units))
-
         # get the conversion factors over to (longitude, latitude)
         origin_lon_lat = origin_long_lat_from_location(location, point)
         convert_facs = meters_to_long_lat_factors(origin_lon_lat)
+        tolerance = self.tolerance if tolerance is None else tolerance
 
         # export each building as a feature in the file
         for _, bldg in enumerate(model.buildings):
@@ -984,7 +1012,7 @@ class Model(_BaseGeometry):
 
         return geojson_dict
 
-    def to_geojson(self, location, point=Point2D(0, 0), folder=None, tolerance=0.01):
+    def to_geojson(self, location, point=Point2D(0, 0), folder=None, tolerance=None):
         """Convert Dragonfly Model to a geoJSON of buildings footprints.
 
         This geoJSON will be in a format that is compatible with the URBANopt SDK,
@@ -1001,8 +1029,8 @@ class Model(_BaseGeometry):
                 If None, a sub-folder within the honeybee default simulation
                 folder will be used. (Default: None).
             tolerance: The minimum distance between points at which they are
-                not considered touching. Default: 0.01, suitable for objects
-                in meters.
+                not considered touching. If None, the Model's own tolerance
+                will be used. (Default: None).
 
         Returns:
             The path to a geoJSON file that contains polygons for all of the
